use lib 't/spec/packages';
use RoleB;

unit role RoleA;

# vim: ft=perl6
